Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(271)

Unified Diff: components/mus/ws/window_tree.h

Issue 1775133003: Moves EventDispatcher from Display to WindowManagerState (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: todo Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/ws/window_manager_state.cc ('k') | components/mus/ws/window_tree.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/ws/window_tree.h
diff --git a/components/mus/ws/window_tree.h b/components/mus/ws/window_tree.h
index 378186de1abc9059b36510362b7df27570c2409b..4dcb880f7a38eb95c24108b52782eaae62a9d555 100644
--- a/components/mus/ws/window_tree.h
+++ b/components/mus/ws/window_tree.h
@@ -109,13 +109,19 @@ class WindowTree : public mojom::WindowTree,
const_cast<const WindowTree*>(this)->GetDisplay(window));
}
+ const WindowManagerState* GetWindowManagerState(
+ const ServerWindow* window) const;
+ WindowManagerState* GetWindowManagerState(const ServerWindow* window) {
+ return const_cast<WindowManagerState*>(
+ const_cast<const WindowTree*>(this)->GetWindowManagerState(window));
+ }
+
// Invoked when a tree is about to be destroyed.
void OnWindowDestroyingTreeImpl(WindowTree* tree);
- void OnWillDestroyDisplay(Display* display);
-
// These functions are synchronous variants of those defined in the mojom. The
// WindowTree implementations all call into these. See the mojom for details.
+ bool SetCapture(const ClientWindowId& client_window_id);
bool NewWindow(const ClientWindowId& client_window_id,
const std::map<std::string, std::vector<uint8_t>>& properties);
bool AddWindow(const ClientWindowId& parent_id,
@@ -406,8 +412,8 @@ class WindowTree : public mojom::WindowTree,
uint32_t event_ack_id_;
- // Display the current event came from.
- Display* event_source_display_;
+ // WindowManager the current event came from.
+ WindowManagerState* event_source_wms_ = nullptr;
bool is_embed_root_;
« no previous file with comments | « components/mus/ws/window_manager_state.cc ('k') | components/mus/ws/window_tree.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698